#include "renderer.h"

static void _renderer_viewport_set(Renderer* self, ivec4 viewport);

/* Sets the renderer's viewport. */
static void
_renderer_viewport_set(Renderer* self, ivec4 viewport)
{
	glViewport(viewport[0], viewport[1], viewport[2], viewport[3]);
}

/* Initializes renderer. */
void
renderer_init(Renderer* self, Window* window, CameraType type)
{
	self->window = window;

	self->glContext = SDL_GL_CreateContext(self->window->sdl);

	glew_init();

	vao_init(&self->vao);
	vbo_init(&self->vbo, GL_ARRAY_BUFFER, true);
	vbo_init(&self->ebo, GL_ELEMENT_ARRAY_BUFFER, true);

	switch (type)
	{
		case CAMERA_ORTHOGRAPHIC:
			camera_orthographic_init(&self->camera, self->window->size);
			break;
		default:
			break;
	}
}

/* Frees renderer. */
void
renderer_free(Renderer* self)
{
	memset(self, '\0', sizeof(Renderer));
	SDL_GL_DeleteContext(self->glContext);
}

/* Sets the renderer's viewport to the window. */
void
renderer_viewport_window_set(Renderer* self)
{
	ivec4 viewport;

	window_ivec4_get(self->window, viewport);

	_renderer_viewport_set(self, viewport);
}

/*
void
renderer_shader_use(Renderer* self, Shader* shader)
{
	self->shader = shader;
	shader_use(shader);
}
*/

/* Sets the renderer clear color. */
void
renderer_clear_color_set(Renderer* self, vec4 color)
{
	glClearColor(color[0], color[1], color[2], color[3]);
}

/* Clears the renderer. */
void
renderer_clear(Renderer* self)
{
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
}

/* Presents renderer. */
void
renderer_present(Renderer* self)
{
	SDL_GL_SwapWindow(self->window->sdl);
}

/* Updates renderer. */
void
renderer_update(Renderer* self)
{
	renderer_viewport_window_set(self);
	
	/*
	camera_update(&self->camera);

	if (self->camera.type == CAMERA_ORTHOGRAPHIC)
		camera_orthographic_window_set(&self->camera, self->window);
	*/
}


