#include "ecs.h"

static void _ecs_function(ECS* self, ECSFunctionType type);

/* Executes a function upon an ECS. */
/* If a component does not have the function specfied, skips. */
static void
_ecs_function(ECS* self, ECSFunctionType type)
{
	for (s32 i = 0; i < ECS_COMPONENT_COUNT; i++)
	{
		ECSFunction function;
		struct ECSComponentList* list;

		list = &game.ecs.lists[i];

		function = list->system.functions[type];

		if (function)
			ecs_component_function(list, function);
	}
}

/* Ticks the ECS. */
void
ecs_tick(ECS* self)
{
	_ecs_function(self, ECS_FUNCTION_TICK);
}

/* Draws the ECS. */
void
ecs_draw(ECS* self)
{
	_ecs_function(self, ECS_FUNCTION_DRAW);
}

/* Initializes ECS. */
void
ecs_init(ECS* self, Game* game)
{
	self->game = game;
}

/* Frees ECS. */
void
ecs_free(ECS* self)
{

}
