#include "game.h"

Game game;

static void _game_tick(Game* self);
static void _game_draw(Game* self);
static void _game_quit(Game* self);

/* Quits game. */
static void
_game_quit(Game* self)
{
	window_free(&self->window);

	sdl_quit();

	memset(self, '\0', sizeof(Game));

	exit(EXIT_SUCCESS);
}

/* Main game tick function. */
static void
_game_tick(Game* self)
{
	renderer_update(&self->renderer);

	event_update(&self->event);

	if (event_press(&self->event, EVENT_QUIT))
		_game_quit(self);
}

/* Main game draw function. */
static void
_game_draw(Game* self)
{
	renderer_present(&self->renderer);

	renderer_clear(&self->renderer);
}

/* Initializes game. */
void
game_init(Game* self)
{
	memset(self, '\0', sizeof(Game));

	sdl_init();

	window_init
	(
		&self->window, 
		WINDOW_TITLE,
		(s32*)WINDOW_SIZE,
		WINDOW_FLAGS
	);

	renderer_init(&self->renderer, &self->window);

	renderer_clear_color_set(&self->renderer, (f32*)RENDERER_CLEAR_COLOR);
}

/* Main game loop. */
void
game_loop(Game* self)
{
	tick_update(&self->tick);

	while (self->tick.cum > 16)
	{
		_game_tick(self);
		
		self->tick.cum -= 16;
	}

	_game_draw(self);
}
